From dd3b19edd78bf2d938d1d84232b9d094c6fa422d Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Torsten=20Sch=C3=B6nfeld?= <kaffeetisch@gmx.de>
Date: Sun, 27 Nov 2011 12:24:30 +0100
Subject: [PATCH] Fix compilation against cairo < 1.8.0

Protect various enum values with version guards.

https://rt.cpan.org/Ticket/Display.html?id=72576
---
 CairoFont.xs    |    4 ++++
 CairoSurface.xs |    4 ++++
 Makefile.PL     |    6 +++---
 3 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/CairoFont.xs b/CairoFont.xs
index 41a4331..5ecd5ac 100644
--- a/CairoFont.xs
+++ b/CairoFont.xs
@@ -28,8 +28,12 @@ get_package (cairo_font_face_t *face)
 
 	    /* These aren't wrapped yet: */
 	    case CAIRO_FONT_TYPE_WIN32:
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 6, 0)
 	    case CAIRO_FONT_TYPE_QUARTZ:
+#endif
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 8, 0)
 	    case CAIRO_FONT_TYPE_USER:
+#endif
 		package = "Cairo::FontFace";
 		break;
 
diff --git a/CairoSurface.xs b/CairoSurface.xs
index 59a4b06..d4d3c82 100644
--- a/CairoSurface.xs
+++ b/CairoSurface.xs
@@ -98,9 +98,13 @@ get_package (cairo_surface_t *surface)
 	    case CAIRO_SURFACE_TYPE_WIN32:
 	    case CAIRO_SURFACE_TYPE_BEOS:
 	    case CAIRO_SURFACE_TYPE_DIRECTFB:
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 4, 0)
 	    case CAIRO_SURFACE_TYPE_OS2:
+#endif
+#if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 6, 0)
 	    case CAIRO_SURFACE_TYPE_WIN32_PRINTING:
 	    case CAIRO_SURFACE_TYPE_QUARTZ_IMAGE:
+#endif
 #if CAIRO_VERSION >= CAIRO_VERSION_ENCODE(1, 10, 0)
 	    case CAIRO_SURFACE_TYPE_SCRIPT:
 	    case CAIRO_SURFACE_TYPE_QT:
diff --git a/Makefile.PL b/Makefile.PL
index 8331096..5591d4b 100644
--- a/Makefile.PL
+++ b/Makefile.PL
@@ -267,9 +267,6 @@ if ($have_cairo_1_2) {
 		CAIRO_SURFACE_TYPE_BEOS
 		CAIRO_SURFACE_TYPE_DIRECTFB
 		CAIRO_SURFACE_TYPE_SVG
-		CAIRO_SURFACE_TYPE_OS2
-		CAIRO_SURFACE_TYPE_WIN32_PRINTING
-		CAIRO_SURFACE_TYPE_QUARTZ_IMAGE
 	/];
 
 	$enums{cairo_svg_version_t} = [qw/
@@ -291,6 +288,7 @@ if ($have_cairo_1_4) {
 	add_new_enum_values(
 		cairo_status_t => [qw/CAIRO_STATUS_INVALID_INDEX
 		                      CAIRO_STATUS_CLIP_NOT_REPRESENTABLE/],
+		cairo_surface_type_t => [qw/CAIRO_SURFACE_TYPE_OS2/],
 	);
 }
 
@@ -299,6 +297,8 @@ if ($have_cairo_1_6) {
 		cairo_font_type_t => [qw/CAIRO_FONT_TYPE_QUARTZ/],
 		cairo_status_t => [qw/CAIRO_STATUS_TEMP_FILE_ERROR
 				      CAIRO_STATUS_INVALID_STRIDE/],
+		cairo_surface_type_t => [qw/CAIRO_SURFACE_TYPE_WIN32_PRINTING
+		                            CAIRO_SURFACE_TYPE_QUARTZ_IMAGE/],
 
 	);
 
-- 
1.7.5.4

